==> firebase_repository-1.0.43.tar.gz: lib/src/entities/carga_entity.dart <==
import 'package:equatable/equatable.dart';
import 'package:cloud_firestore/cloud_firestore.dart';

class CargaEntity extends Equatable {
  final bool activo;
  final String uuid;
  final double agua;
  final double costo;
  final String dietaUuid;
  final double disponibles;
  final DateTime fecha;
  final double materiaSeca;
  final String mixerUuid;
  final double porcentaje;
  final double talcual;
  final double totalcarga;
  final String usuarioUuid;
  final List<dynamic> ingredientes;

  CargaEntity(
      this.activo,
      this.uuid,
      this.agua,
      this.costo,
      this.dietaUuid,
      this.disponibles,
      this.fecha,
      this.materiaSeca,
      this.mixerUuid,
      this.porcentaje,
      this.talcual,
      this.totalcarga,
      this.usuarioUuid,
      this.ingredientes);

  Map<String, Object> toJson() {
    return {
      'activo': this.activo,
      'agua': this.agua,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'disponibles': this.disponibles,
      'fecha': this.fecha,
      'materiaSeca': this.materiaSeca,
      'mixerUuid': this.mixerUuid,
      'porcentaje': this.porcentaje,
      'talcual': this.talcual,
      'totalcarga': this.totalcarga,
      'usuarioUuid': this.usuarioUuid,
      'ingredientes': this.ingredientes
    };
  }

  Map<String, Object> toMap() {
    return {
      'activo': this.activo,
      'uuid': this.uuid,
      'agua': this.agua,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'disponibles': this.disponibles,
      'fecha': this.fecha,
      'materiaSeca': this.materiaSeca,
      'mixerUuid': this.mixerUuid,
      'porcentaje': this.porcentaje,
      'talcual': this.talcual,
      'totalcarga': this.totalcarga,
      'usuarioUuid': this.usuarioUuid,
      'ingredientes': this.ingredientes
    };
  }

  CargaEntity.fromMap(Map<dynamic, dynamic> data)
      : activo = data['activo'],
        uuid = data['uuid'],
        agua = data['agua'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        disponibles = data['disponibles'],
        fecha = data['fecha'],
        materiaSeca = data['materiaSeca'],
        mixerUuid = data['mixerUuid'],
        porcentaje = data['porcentaje'],
        talcual = data['talcual'],
        totalcarga = data['totalcarga'],
        usuarioUuid = data['usuarioUuid'],
        ingredientes = data['ingredientes'];


  @override
  String toString() {
    return 'CargaEntity{activo: $activo, uuid: $uuid, agua: $agua, costo: $costo, dietaUuid: $dietaUuid, disponibles: $disponibles, fecha: $fecha, materiaSeca: $materiaSeca, mixerUuid: $mixerUuid, porcentaje: $porcentaje, talcual: $talcual, totalcarga: $totalcarga, usuarioUuid: $usuarioUuid, ingredientes: $ingredientes}';
  }

  CargaEntity.fromJson(Map<String, dynamic> data)
      : activo = data['activo'],
        uuid = data['uuid'],
        agua = data['agua'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        disponibles = data['disponibles'],
        fecha = data['fecha'],
        materiaSeca = data['materiaSeca'],
        mixerUuid = data['mixerUuid'],
        porcentaje = data['porcentaje'],
        talcual = data['talcual'],
        totalcarga = data['totalcarga'],
        usuarioUuid = data['usuarioUuid'],
        ingredientes = data['ingredientes'];

  CargaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : activo = snapshot.data['activo'],
        uuid = snapshot.documentID,
        agua = snapshot.data['agua'] is double
            ? snapshot.data['agua']
            : double.parse(snapshot.data['agua'].toString()),
        costo = snapshot.data['costo'],
        dietaUuid = snapshot.data['dieta'],
        disponibles = snapshot.data['disponibles'],
        fecha =
            (snapshot.data['fecha'] is int || snapshot.data['fecha'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['fecha'].round().toInt())
                : snapshot.data['fecha'].toDate(),
        materiaSeca = snapshot.data['materiaSeca'],
        mixerUuid = snapshot.data['mixerUuid'],
        porcentaje = snapshot.data['porcentaje'],
        talcual = snapshot.data['talcual'],
        totalcarga = snapshot.data['totalcarga'].runtimeType == double
            ? snapshot.data['totalcarga']
            : double.parse(snapshot.data['totalcarga'].toString()),
        usuarioUuid = snapshot.data['usuarioUuid'],
        ingredientes = snapshot.data['ingredientes'];

  Map<String, Object> toDocument() {
    return {
      'activo': this.activo,
      'agua': this.agua,
      'costo': this.costo,
      'dieta': this.dietaUuid,
      'disponibles': this.disponibles,
      'fecha': this.fecha.millisecondsSinceEpoch,
      'materiaseca': this.materiaSeca,
      'mixer': this.mixerUuid,
      'porcentaje': this.porcentaje,
      'talcual': this.talcual,
      'totalcarga': this.totalcarga,
      'usuario': this.usuarioUuid,
      'ingredientes': this.ingredientes
    };
  }
}

==> firebase_repository-1.0.46.tar.gz: lib/src/entities/carga_entity.dart <==
import 'package:equatable/equatable.dart';
import 'package:cloud_firestore/cloud_firestore.dart';

class CargaEntity extends Equatable {
  final bool activo;
  final String uuid;
  final double agua;
  final double costo;
  final String dietaUuid;
  final double disponibles;
  final DateTime fecha;
  final double materiaSeca;
  final String mixerUuid;
  final double porcentaje;
  final double talcual;
  final double totalcarga;
  final String usuarioUuid;
  final List<dynamic> ingredientes;

  CargaEntity(
      this.activo,
      this.uuid,
      this.agua,
      this.costo,
      this.dietaUuid,
      this.disponibles,
      this.fecha,
      this.materiaSeca,
      this.mixerUuid,
      this.porcentaje,
      this.talcual,
      this.totalcarga,
      this.usuarioUuid,
      this.ingredientes);

  Map<String, Object> toJson() {
    return {
      'activo': this.activo,
      'agua': this.agua,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'disponibles': this.disponibles,
      'fecha': this.fecha,
      'materiaSeca': this.materiaSeca,
      'mixerUuid': this.mixerUuid,
      'porcentaje': this.porcentaje,
      'talcual': this.talcual,
      'totalcarga': this.totalcarga,
      'usuarioUuid': this.usuarioUuid,
      'ingredientes': this.ingredientes
    };
  }

  Map<String, Object> toMap() {
    return {
      'activo': this.activo,
      'uuid': this.uuid,
      'agua': this.agua,
      'costo': this.costo,
      'dietaUuid': this.dietaUuid,
      'disponibles': this.disponibles,
      'fecha': this.fecha,
      'materiaSeca': this.materiaSeca,
      'mixerUuid': this.mixerUuid,
      'porcentaje': this.porcentaje,
      'talcual': this.talcual,
      'totalcarga': this.totalcarga,
      'usuarioUuid': this.usuarioUuid,
      'ingredientes': this.ingredientes
    };
  }

  CargaEntity.fromMap(Map<dynamic, dynamic> data)
      : activo = data['activo'],
        uuid = data['uuid'],
        agua = data['agua'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        disponibles = data['disponibles'],
        fecha = data['fecha'],
        materiaSeca = data['materiaSeca'],
        mixerUuid = data['mixerUuid'],
        porcentaje = data['porcentaje'],
        talcual = data['talcual'],
        totalcarga = data['totalcarga'],
        usuarioUuid = data['usuarioUuid'],
        ingredientes = data['ingredientes'];


  @override
  String toString() {
    return 'CargaEntity{activo: $activo, uuid: $uuid, agua: $agua, costo: $costo, dietaUuid: $dietaUuid, disponibles: $disponibles, fecha: $fecha, materiaSeca: $materiaSeca, mixerUuid: $mixerUuid, porcentaje: $porcentaje, talcual: $talcual, totalcarga: $totalcarga, usuarioUuid: $usuarioUuid, ingredientes: $ingredientes}';
  }

  CargaEntity.fromJson(Map<String, dynamic> data)
      : activo = data['activo'],
        uuid = data['uuid'],
        agua = data['agua'],
        costo = data['costo'],
        dietaUuid = data['dietaUuid'],
        disponibles = data['disponibles'],
        fecha = data['fecha'],
        materiaSeca = data['materiaSeca'],
        mixerUuid = data['mixerUuid'],
        porcentaje = data['porcentaje'],
        talcual = data['talcual'],
        totalcarga = data['totalcarga'],
        usuarioUuid = data['usuarioUuid'],
        ingredientes = data['ingredientes'];

  CargaEntity.fromSnapshot(DocumentSnapshot snapshot)
      : activo = snapshot.data['activo'],
        uuid = snapshot.documentID,
        agua = snapshot.data['agua'] is double
            ? snapshot.data['agua']
            : double.parse(snapshot.data['agua'].toString()),
        costo = snapshot.data['costo'],
        dietaUuid = snapshot.data['dieta'],
        disponibles = snapshot.data['disponibles'],
        fecha =
            (snapshot.data['fecha'] is int || snapshot.data['fecha'] is double)
                ? DateTime.fromMillisecondsSinceEpoch(
                    snapshot.data['fecha'].round().toInt())
                : snapshot.data['fecha'].toDate(),
        materiaSeca = snapshot.data['materiaseca'],
        mixerUuid = snapshot.data['mixerUuid'],
        porcentaje = snapshot.data['porcentaje'],
        talcual = snapshot.data['talcual'],
        totalcarga = snapshot.data['totalcarga'].runtimeType == double
            ? snapshot.data['totalcarga']
            : double.parse(snapshot.data['totalcarga'].toString()),
        usuarioUuid = snapshot.data['usuarioUuid'],
        ingredientes = snapshot.data['ingredientes'];

  Map<String, Object> toDocument() {
    return {
      'activo': this.activo,
      'agua': this.agua,
      'costo': this.costo,
      'dieta': this.dietaUuid,
      'disponibles': this.disponibles,
      'fecha': this.fecha.millisecondsSinceEpoch,
      'materiaseca': this.materiaSeca,
      'mixer': this.mixerUuid,
      'porcentaje': this.porcentaje,
      'talcual': this.talcual,
      'totalcarga': this.totalcarga,
      'usuario': this.usuarioUuid,
      'ingredientes': this.ingredientes
    };
  }
}
